@@ -1,9 +1,10 @@
-from collections import OrderedDict
+import math
 import types
 
 import numpy as np
 
-from matplotlib import _api, cbook, rcParams
+import matplotlib as mpl
+from matplotlib import _api, cbook
 from matplotlib.axes import Axes
 import matplotlib.axis as maxis
 import matplotlib.markers as mmarkers
@@ -11,42 +12,69 @@ import matplotlib.patches as mpatches
 from matplotlib.path import Path
 import matplotlib.ticker as mticker
 import matplotlib.transforms as mtransforms
-import matplotlib.spines as mspines
+from matplotlib.spines import Spine
 
 
 class PolarTransform(mtransforms.Transform):
+    r"""
+    The base polar transform.
+
+    This transform maps polar coordinates :math:`\theta, r` into Cartesian
+    coordinates :math:`x, y = r \cos(\theta), r \sin(\theta)`
+    (but does not fully transform into Axes coordinates or
+    handle positioning in screen space).
+
+    This transformation is designed to be applied to data after any scaling
+    along the radial axis (e.g. log-scaling) has been applied to the input
+    data.
+
+    Path segments at a fixed radius are automatically transformed to circular
+    arcs as long as ``path._interpolation_steps > 1``.
     """
-    The base polar transform.  This handles projection *theta* and
-    *r* into Cartesian coordinate space *x* and *y*, but does not
-    perform the ultimate affine transformation into the correct
-    position.
-    """
+
     input_dims = output_dims = 2
 
     def __init__(self, axis=None, use_rmin=True,
-                 _apply_theta_transforms=True):
+                 _apply_theta_transforms=True, *, scale_transform=None):
+        """
+        Parameters
+        ----------
+        axis : `~matplotlib.axis.Axis`, optional
+            Axis associated with this transform. This is used to get the
+            minimum radial limit.
+        use_rmin : `bool`, optional
+            If ``True``, subtract the minimum radial axis limit before
+            transforming to Cartesian coordinates. *axis* must also be
+            specified for this to take effect.
+        """
         super().__init__()
         self._axis = axis
         self._use_rmin = use_rmin
         self._apply_theta_transforms = _apply_theta_transforms
+        self._scale_transform = scale_transform
 
     __str__ = mtransforms._make_str_method(
         "_axis",
         use_rmin="_use_rmin",
         _apply_theta_transforms="_apply_theta_transforms")
 
+    def _get_rorigin(self):
+        # Get lower r limit after being scaled by the radial scale transform
+        return self._scale_transform.transform(
+            (0, self._axis.get_rorigin()))[1]
+
     def transform_non_affine(self, tr):
         # docstring inherited
-        t, r = np.transpose(tr)
+        theta, r = np.transpose(tr)
         # PolarAxes does not use the theta transforms here, but apply them for
         # backwards-compatibility if not being used by it.
         if self._apply_theta_transforms and self._axis is not None:
-            t *= self._axis.get_theta_direction()
-            t += self._axis.get_theta_offset()
+            theta *= self._axis.get_theta_direction()
+            theta += self._axis.get_theta_offset()
         if self._use_rmin and self._axis is not None:
-            r = (r - self._axis.get_rorigin()) * self._axis.get_rsign()
+            r = (r - self._get_rorigin()) * self._axis.get_rsign()
         r = np.where(r >= 0, r, np.nan)
-        return np.column_stack([r * np.cos(t), r * np.sin(t)])
+        return np.column_stack([r * np.cos(theta), r * np.sin(theta)])
 
     def transform_path_non_affine(self, path):
         # docstring inherited
@@ -68,7 +96,7 @@ class PolarTransform(mtransforms.Transform):
                     # that behavior here.
                     last_td, td = np.rad2deg([last_t, t])
                     if self._use_rmin and self._axis is not None:
-                        r = ((r - self._axis.get_rorigin())
+                        r = ((r - self._get_rorigin())
                              * self._axis.get_rsign())
                     if last_td <= td:
                         while td - last_td > 360:
@@ -109,15 +137,30 @@ class PolarTransform(mtransforms.Transform):
 
 
 class PolarAffine(mtransforms.Affine2DBase):
-    """
-    The affine part of the polar projection.  Scales the output so
-    that maximum radius rests on the edge of the axes circle.
+    r"""
+    The affine part of the polar projection.
+
+    Scales the output so that maximum radius rests on the edge of the axes
+    circle and the origin is mapped to (0.5, 0.5). The transform applied is
+    the same to x and y components and given by:
+
+    .. math::
+
+        x_{1} = 0.5 \left [ \frac{x_{0}}{(r_{\max} - r_{\min})} + 1 \right ]
+
+    :math:`r_{\min}, r_{\max}` are the minimum and maximum radial limits after
+    any scaling (e.g. log scaling) has been removed.
     """
     def __init__(self, scale_transform, limits):
         """
-        *limits* is the view limit of the data.  The only part of
-        its bounds that is used is the y limits (for the radius limits).
-        The theta range is handled by the non-affine transform.
+        Parameters
+        ----------
+        scale_transform : `~matplotlib.transforms.Transform`
+            Scaling transform for the data. This is used to remove any scaling
+            from the radial view limits.
+        limits : `~matplotlib.transforms.BboxBase`
+            View limits of the data. The only part of its bounds that is used
+            is the y limits (for the radius limits).
         """
         super().__init__()
         self._scale_transform = scale_transform
@@ -150,6 +193,17 @@ class InvertedPolarTransform(mtransforms.Transform):
 
     def __init__(self, axis=None, use_rmin=True,
                  _apply_theta_transforms=True):
+        """
+        Parameters
+        ----------
+        axis : `~matplotlib.axis.Axis`, optional
+            Axis associated with this transform. This is used to get the
+            minimum radial limit.
+        use_rmin : `bool`, optional
+            If ``True`` add the minimum radial axis limit after
+            transforming from Cartesian coordinates. *axis* must also be
+            specified for this to take effect.
+        """
         super().__init__()
         self._axis = axis
         self._use_rmin = use_rmin
@@ -187,11 +241,12 @@ class ThetaFormatter(mticker.Formatter):
     Used to format the *theta* tick labels.  Converts the native
     unit of radians into degrees and adds a degree symbol.
     """
+
     def __call__(self, x, pos=None):
         vmin, vmax = self.axis.get_view_interval()
         d = np.rad2deg(abs(vmax - vmin))
         digits = max(-int(np.log10(d) - 1.5), 0)
-        # Use unicode rather than mathtext with \circ, so that it will work
+        # Use Unicode rather than mathtext with \circ, so that it will work
         # correctly with any arbitrary font (assuming it has a degree sign),
         # whereas $5\circ$ will only work correctly with one of the supported
         # math fonts (Computer Modern and STIX).
@@ -246,22 +301,10 @@ class ThetaLocator(mticker.Locator):
         else:
             return np.deg2rad(self.base())
 
-    @_api.deprecated("3.3")
-    def pan(self, numsteps):
-        return self.base.pan(numsteps)
-
-    def refresh(self):
-        # docstring inherited
-        return self.base.refresh()
-
     def view_limits(self, vmin, vmax):
         vmin, vmax = np.rad2deg((vmin, vmax))
         return np.deg2rad(self.base.view_limits(vmin, vmax))
 
-    @_api.deprecated("3.3")
-    def zoom(self, direction):
-        return self.base.zoom(direction)
-
 
 class ThetaTick(maxis.XTick):
     """
@@ -290,9 +333,8 @@ class ThetaTick(maxis.XTick):
             rotation_mode='anchor',
             transform=self.label2.get_transform() + self._text2_translate)
 
-    def _apply_params(self, **kw):
-        super()._apply_params(**kw)
-
+    def _apply_params(self, **kwargs):
+        super()._apply_params(**kwargs)
         # Ensure transform is correct; sometimes this gets reset.
         trans = self.label1.get_transform()
         if not trans.contains_branch(self._text1_translate):
@@ -365,13 +407,7 @@ class ThetaAxis(maxis.XAxis):
     """
     __name__ = 'thetaaxis'
     axis_name = 'theta'  #: Read-only name identifying the axis.
-
-    def _get_tick(self, major):
-        if major:
-            tick_kw = self._major_tick_kw
-        else:
-            tick_kw = self._minor_tick_kw
-        return ThetaTick(self.axes, 0, major=major, **tick_kw)
+    _tick_class = ThetaTick
 
     def _wrap_locator_formatter(self):
         self.set_major_locator(ThetaLocator(self.get_major_locator()))
@@ -380,16 +416,20 @@ class ThetaAxis(maxis.XAxis):
         self.isDefault_majfmt = True
 
     def clear(self):
+        # docstring inherited
         super().clear()
         self.set_ticks_position('none')
         self._wrap_locator_formatter()
 
-    @_api.deprecated("3.4", alternative="ThetaAxis.clear()")
-    def cla(self):
-        self.clear()
-
     def _set_scale(self, value, **kwargs):
+        if value != 'linear':
+            raise NotImplementedError(
+                "The xscale cannot be set on a polar plot")
         super()._set_scale(value, **kwargs)
+        # LinearScale.set_default_locators_and_formatters just set the major
+        # locator to be an AutoLocator, so we customize it here to have ticks
+        # at sensible degree multiples.
+        self.get_major_locator().set_params(steps=[1, 1.5, 3, 4.5, 9, 10])
         self._wrap_locator_formatter()
 
     def _copy_tick_props(self, src, dest):
@@ -418,40 +458,37 @@ class RadialLocator(mticker.Locator):
         self.base = base
         self._axes = axes
 
+    def set_axis(self, axis):
+        self.base.set_axis(axis)
+
     def __call__(self):
-        show_all = True
         # Ensure previous behaviour with full circle non-annular views.
         if self._axes:
             if _is_full_circle_rad(*self._axes.viewLim.intervalx):
                 rorigin = self._axes.get_rorigin() * self._axes.get_rsign()
                 if self._axes.get_rmin() <= rorigin:
-                    show_all = False
-        if show_all:
-            return self.base()
-        else:
-            return [tick for tick in self.base() if tick > rorigin]
+                    return [tick for tick in self.base() if tick > rorigin]
+        return self.base()
 
-    @_api.deprecated("3.3")
-    def pan(self, numsteps):
-        return self.base.pan(numsteps)
-
-    @_api.deprecated("3.3")
-    def zoom(self, direction):
-        return self.base.zoom(direction)
-
-    @_api.deprecated("3.3")
-    def refresh(self):
-        # docstring inherited
-        return self.base.refresh()
+    def _zero_in_bounds(self):
+        """
+        Return True if zero is within the valid values for the
+        scale of the radial axis.
+        """
+        vmin, vmax = self._axes.yaxis._scale.limit_range_for_scale(0, 1, 1e-5)
+        return vmin == 0
 
     def nonsingular(self, vmin, vmax):
         # docstring inherited
-        return ((0, 1) if (vmin, vmax) == (-np.inf, np.inf)  # Init. limits.
-                else self.base.nonsingular(vmin, vmax))
+        if self._zero_in_bounds() and (vmin, vmax) == (-np.inf, np.inf):
+            # Initial view limits
+            return (0, 1)
+        else:
+            return self.base.nonsingular(vmin, vmax)
 
     def view_limits(self, vmin, vmax):
         vmin, vmax = self.base.view_limits(vmin, vmax)
-        if vmax > vmin:
+        if self._zero_in_bounds() and vmax > vmin:
             # this allows inverted r/y-lims
             vmin = min(0, vmin)
         return mtransforms.nonsingular(vmin, vmax)
@@ -667,32 +704,23 @@ class RadialAxis(maxis.YAxis):
     """
     __name__ = 'radialaxis'
     axis_name = 'radius'  #: Read-only name identifying the axis.
+    _tick_class = RadialTick
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.sticky_edges.y.append(0)
 
-    def _get_tick(self, major):
-        if major:
-            tick_kw = self._major_tick_kw
-        else:
-            tick_kw = self._minor_tick_kw
-        return RadialTick(self.axes, 0, major=major, **tick_kw)
-
     def _wrap_locator_formatter(self):
         self.set_major_locator(RadialLocator(self.get_major_locator(),
                                              self.axes))
         self.isDefault_majloc = True
 
     def clear(self):
+        # docstring inherited
         super().clear()
         self.set_ticks_position('none')
         self._wrap_locator_formatter()
 
-    @_api.deprecated("3.4", alternative="RadialAxis.clear()")
-    def cla(self):
-        self.clear()
-
     def _set_scale(self, value, **kwargs):
         super()._set_scale(value, **kwargs)
         self._wrap_locator_formatter()
@@ -790,10 +818,11 @@ class PolarAxes(Axes):
         super().__init__(*args, **kwargs)
         self.use_sticky_edges = True
         self.set_aspect('equal', adjustable='box', anchor='C')
-        self.cla()
+        self.clear()
 
-    def cla(self):
-        super().cla()
+    def clear(self):
+        # docstring inherited
+        super().clear()
 
         self.title.set_y(1.05)
 
@@ -805,7 +834,7 @@ class PolarAxes(Axes):
             end.set_visible(False)
         self.set_xlim(0.0, 2 * np.pi)
 
-        self.grid(rcParams['polaraxes.grid'])
+        self.grid(mpl.rcParams['polaraxes.grid'])
         inner = self.spines.get('inner', None)
         if inner:
             inner.set_visible(False)
@@ -818,11 +847,9 @@ class PolarAxes(Axes):
         # This is moved out of __init__ because non-separable axes don't use it
         self.xaxis = ThetaAxis(self)
         self.yaxis = RadialAxis(self)
-        # Calling polar_axes.xaxis.clear() or polar_axes.xaxis.clear()
-        # results in weird artifacts. Therefore we disable this for
-        # now.
+        # Calling polar_axes.xaxis.clear() or polar_axes.yaxis.clear()
+        # results in weird artifacts. Therefore we disable this for now.
         # self.spines['polar'].register_axis(self.yaxis)
-        self._update_transScale()
 
     def _set_lim_and_transforms(self):
         # A view limit where the minimum radius can be locked if the user
@@ -861,7 +888,9 @@ class PolarAxes(Axes):
         # data.  This one is aware of rmin
         self.transProjection = self.PolarTransform(
             self,
-            _apply_theta_transforms=False)
+            _apply_theta_transforms=False,
+            scale_transform=self.transScale
+        )
         # Add dependency on rorigin.
         self.transProjection.set_children(self._originViewLim)
 
@@ -872,9 +901,25 @@ class PolarAxes(Axes):
 
         # The complete data transformation stack -- from data all the
         # way to display coordinates
+        #
+        # 1. Remove any radial axis scaling (e.g. log scaling)
+        # 2. Shift data in the theta direction
+        # 3. Project the data from polar to cartesian values
+        #    (with the origin in the same place)
+        # 4. Scale and translate the cartesian values to Axes coordinates
+        #    (here the origin is moved to the lower left of the Axes)
+        # 5. Move and scale to fill the Axes
+        # 6. Convert from Axes coordinates to Figure coordinates
         self.transData = (
-            self.transScale + self.transShift + self.transProjection +
-            (self.transProjectionAffine + self.transWedge + self.transAxes))
+            self.transScale +
+            self.transShift +
+            self.transProjection +
+            (
+                self.transProjectionAffine +
+                self.transWedge +
+                self.transAxes
+            )
+        )
 
         # This is the transform for theta-axis ticks.  It is
         # equivalent to transData, except it always puts r == 0.0 and r == 1.0
@@ -945,9 +990,7 @@ class PolarAxes(Axes):
             pad_shift = _ThetaShift(self, pad, 'min')
         return self._yaxis_text_transform + pad_shift, 'center', halign
 
-    @_api.delete_parameter("3.3", "args")
-    @_api.delete_parameter("3.3", "kwargs")
-    def draw(self, renderer, *args, **kwargs):
+    def draw(self, renderer):
         self._unstale_viewLim()
         thetamin, thetamax = np.rad2deg(self._realViewLim.intervalx)
         if thetamin > thetamax:
@@ -991,20 +1034,18 @@ class PolarAxes(Axes):
             self.yaxis.reset_ticks()
             self.yaxis.set_clip_path(self.patch)
 
-        super().draw(renderer, *args, **kwargs)
+        super().draw(renderer)
 
     def _gen_axes_patch(self):
         return mpatches.Wedge((0.5, 0.5), 0.5, 0.0, 360.0)
 
     def _gen_axes_spines(self):
-        spines = OrderedDict([
-            ('polar', mspines.Spine.arc_spine(self, 'top',
-                                              (0.5, 0.5), 0.5, 0.0, 360.0)),
-            ('start', mspines.Spine.linear_spine(self, 'left')),
-            ('end', mspines.Spine.linear_spine(self, 'right')),
-            ('inner', mspines.Spine.arc_spine(self, 'bottom',
-                                              (0.5, 0.5), 0.0, 0.0, 360.0))
-        ])
+        spines = {
+            'polar': Spine.arc_spine(self, 'top', (0.5, 0.5), 0.5, 0, 360),
+            'start': Spine.linear_spine(self, 'left'),
+            'end': Spine.linear_spine(self, 'right'),
+            'inner': Spine.arc_spine(self, 'bottom', (0.5, 0.5), 0.0, 0, 360),
+        }
         spines['polar'].set_transform(self.transWedge + self.transAxes)
         spines['inner'].set_transform(self.transWedge + self.transAxes)
         spines['start'].set_transform(self._yaxis_transform)
@@ -1040,7 +1081,7 @@ class PolarAxes(Axes):
         where minval and maxval are the minimum and maximum limits. Values are
         wrapped in to the range :math:`[0, 2\pi]` (in radians), so for example
         it is possible to do ``set_thetalim(-np.pi / 2, np.pi / 2)`` to have
-        an axes symmetric around 0. A ValueError is raised if the absolute
+        an axis symmetric around 0. A ValueError is raised if the absolute
         angle difference is larger than a full circle.
         """
         orig_lim = self.get_xlim()  # in radians
@@ -1188,9 +1229,17 @@ class PolarAxes(Axes):
     def get_rsign(self):
         return np.sign(self._originViewLim.y1 - self._originViewLim.y0)
 
+    @_api.make_keyword_only("3.6", "emit")
     def set_rlim(self, bottom=None, top=None, emit=True, auto=False, **kwargs):
         """
-        See `~.polar.PolarAxes.set_ylim`.
+        Set the radial axis view limits.
+
+        This function behaves like `.Axes.set_ylim`, but additionally supports
+        *rmin* and *rmax* as aliases for *bottom* and *top*.
+
+        See Also
+        --------
+        .Axes.set_ylim
         """
         if 'rmin' in kwargs:
             if bottom is None:
@@ -1207,58 +1256,6 @@ class PolarAxes(Axes):
         return self.set_ylim(bottom=bottom, top=top, emit=emit, auto=auto,
                              **kwargs)
 
-    def set_ylim(self, bottom=None, top=None, emit=True, auto=False,
-                 *, ymin=None, ymax=None):
-        """
-        Set the data limits for the radial axis.
-
-        Parameters
-        ----------
-        bottom : float, optional
-            The bottom limit (default: None, which leaves the bottom
-            limit unchanged).
-            The bottom and top ylims may be passed as the tuple
-            (*bottom*, *top*) as the first positional argument (or as
-            the *bottom* keyword argument).
-
-        top : float, optional
-            The top limit (default: None, which leaves the top limit
-            unchanged).
-
-        emit : bool, default: True
-            Whether to notify observers of limit change.
-
-        auto : bool or None, default: False
-            Whether to turn on autoscaling of the y-axis. True turns on,
-            False turns off, None leaves unchanged.
-
-        ymin, ymax : float, optional
-            These arguments are deprecated and will be removed in a future
-            version.  They are equivalent to *bottom* and *top* respectively,
-            and it is an error to pass both *ymin* and *bottom* or
-            *ymax* and *top*.
-
-        Returns
-        -------
-        bottom, top : (float, float)
-            The new y-axis limits in data coordinates.
-        """
-        if ymin is not None:
-            if bottom is not None:
-                raise ValueError('Cannot supply both positional "bottom" '
-                                 'argument and kwarg "ymin"')
-            else:
-                bottom = ymin
-        if ymax is not None:
-            if top is not None:
-                raise ValueError('Cannot supply both positional "top" '
-                                 'argument and kwarg "ymax"')
-            else:
-                top = ymax
-        if top is None and np.iterable(bottom):
-            bottom, top = bottom[0], bottom[1]
-        return super().set_ylim(bottom=bottom, top=top, emit=emit, auto=auto)
-
     def get_rlabel_position(self):
         """
         Returns
@@ -1319,7 +1316,7 @@ class PolarAxes(Axes):
         Other Parameters
         ----------------
         **kwargs
-            *kwargs* are optional `~.Text` properties for the labels.
+            *kwargs* are optional `.Text` properties for the labels.
 
         See Also
         --------
@@ -1337,7 +1334,7 @@ class PolarAxes(Axes):
         elif fmt is not None:
             self.xaxis.set_major_formatter(mticker.FormatStrFormatter(fmt))
         for t in self.xaxis.get_ticklabels():
-            t.update(kwargs)
+            t._internal_update(kwargs)
         return self.xaxis.get_ticklines(), self.xaxis.get_ticklabels()
 
     def set_rgrids(self, radii, labels=None, angle=None, fmt=None, **kwargs):
@@ -1371,7 +1368,7 @@ class PolarAxes(Axes):
         Other Parameters
         ----------------
         **kwargs
-            *kwargs* are optional `~.Text` properties for the labels.
+            *kwargs* are optional `.Text` properties for the labels.
 
         See Also
         --------
@@ -1392,21 +1389,39 @@ class PolarAxes(Axes):
             angle = self.get_rlabel_position()
         self.set_rlabel_position(angle)
         for t in self.yaxis.get_ticklabels():
-            t.update(kwargs)
+            t._internal_update(kwargs)
         return self.yaxis.get_gridlines(), self.yaxis.get_ticklabels()
 
-    def set_xscale(self, scale, *args, **kwargs):
-        if scale != 'linear':
-            raise NotImplementedError(
-                "You can not set the xscale on a polar plot.")
-
     def format_coord(self, theta, r):
         # docstring inherited
+        screen_xy = self.transData.transform((theta, r))
+        screen_xys = screen_xy + np.stack(
+            np.meshgrid([-1, 0, 1], [-1, 0, 1])).reshape((2, -1)).T
+        ts, rs = self.transData.inverted().transform(screen_xys).T
+        delta_t = abs((ts - theta + np.pi) % (2 * np.pi) - np.pi).max()
+        delta_t_halfturns = delta_t / np.pi
+        delta_t_degrees = delta_t_halfturns * 180
+        delta_r = abs(rs - r).max()
         if theta < 0:
             theta += 2 * np.pi
-        theta /= np.pi
-        return ('\N{GREEK SMALL LETTER THETA}=%0.3f\N{GREEK SMALL LETTER PI} '
-                '(%0.3f\N{DEGREE SIGN}), r=%0.3f') % (theta, theta * 180.0, r)
+        theta_halfturns = theta / np.pi
+        theta_degrees = theta_halfturns * 180
+
+        # See ScalarFormatter.format_data_short.  For r, use #g-formatting
+        # (as for linear axes), but for theta, use f-formatting as scientific
+        # notation doesn't make sense and the trailing dot is ugly.
+        def format_sig(value, delta, opt, fmt):
+            # For "f", only count digits after decimal point.
+            prec = (max(0, -math.floor(math.log10(delta))) if fmt == "f" else
+                    cbook._g_sig_digits(value, delta))
+            return f"{value:-{opt}.{prec}{fmt}}"
+
+        return ('\N{GREEK SMALL LETTER THETA}={}\N{GREEK SMALL LETTER PI} '
+                '({}\N{DEGREE SIGN}), r={}').format(
+                    format_sig(theta_halfturns, delta_t_halfturns, "", "f"),
+                    format_sig(theta_degrees, delta_t_degrees, "", "f"),
+                    format_sig(r, delta_r, "#", "g"),
+                )
 
     def get_data_ratio(self):
         """
@@ -1419,17 +1434,17 @@ class PolarAxes(Axes):
 
     def can_zoom(self):
         """
-        Return whether this axes supports the zoom box button functionality.
+        Return whether this Axes supports the zoom box button functionality.
 
-        Polar axes do not support zoom boxes.
+        A polar Axes does not support zoom boxes.
         """
         return False
 
     def can_pan(self):
         """
-        Return whether this axes supports the pan/zoom button functionality.
+        Return whether this Axes supports the pan/zoom button functionality.
 
-        For polar axes, this is slightly misleading. Both panning and
+        For a polar Axes, this is slightly misleading. Both panning and
         zooming are performed by the same button. Panning is performed
         in azimuth while zooming is done along the radial.
         """
@@ -1486,9 +1501,12 @@ class PolarAxes(Axes):
             self.set_rmax(p.rmax / scale)
 
 
-# to keep things all self contained, we can put aliases to the Polar classes
+# To keep things all self-contained, we can put aliases to the Polar classes
 # defined above. This isn't strictly necessary, but it makes some of the
-# code more readable (and provides a backwards compatible Polar API)
+# code more readable, and provides a backwards compatible Polar API. In
+# particular, this is used by the :doc:`/gallery/specialty_plots/radar_chart`
+# example to override PolarTransform on a PolarAxes subclass, so make sure that
+# that example is unaffected before changing this.
 PolarAxes.PolarTransform = PolarTransform
 PolarAxes.PolarAffine = PolarAffine
 PolarAxes.InvertedPolarTransform = InvertedPolarTransform
