@@ -19,7 +19,7 @@ import math
 import numpy as np
 from numpy import ma
 
-from matplotlib import _api, cbook, docstring, font_manager
+from matplotlib import _api, cbook, _docstring
 import matplotlib.artist as martist
 import matplotlib.collections as mcollections
 from matplotlib.patches import CirclePolygon
@@ -32,34 +32,28 @@ Plot a 2D field of arrows.
 
 Call signature::
 
-  quiver([X, Y], U, V, [C], **kw)
+  quiver([X, Y], U, V, [C], **kwargs)
 
 *X*, *Y* define the arrow locations, *U*, *V* define the arrow directions, and
 *C* optionally sets the color.
 
-Each arrow is internally represented by a filled polygon with a default edge
-linewidth of 0. As a result, an arrow is rather a filled area, not a line with
-a head, and `.PolyCollection` properties like *linewidth*, *linestyle*,
-*facecolor*, etc. act accordingly.
-
-**Arrow size**
+**Arrow length**
 
 The default settings auto-scales the length of the arrows to a reasonable size.
 To change this behavior see the *scale* and *scale_units* parameters.
 
 **Arrow shape**
 
-The defaults give a slightly swept-back arrow; to make the head a
-triangle, make *headaxislength* the same as *headlength*. To make the
-arrow more pointed, reduce *headwidth* or increase *headlength* and
-*headaxislength*. To make the head smaller relative to the shaft,
-scale down all the head parameters. You will probably do best to leave
-minshaft alone.
+The arrow shape is determined by *width*, *headwidth*, *headlength* and
+*headaxislength*. See the notes below.
 
-**Arrow outline**
+**Arrow styling**
+
+Each arrow is internally represented by a filled polygon with a default edge
+linewidth of 0. As a result, an arrow is rather a filled area, not a line with
+a head, and `.PolyCollection` properties like *linewidth*, *edgecolor*,
+*facecolor*, etc. act accordingly.
 
-*linewidths* and *edgecolors* can be used to customize the arrow
-outlines.
 
 Parameters
 ----------
@@ -74,11 +68,12 @@ X, Y : 1D or 2D array-like, optional
     must match the column and row dimensions of *U* and *V*.
 
 U, V : 1D or 2D array-like
-    The x and y direction components of the arrow vectors.
+    The x and y direction components of the arrow vectors. The interpretation
+    of these components (in data or in screen space) depends on *angles*.
 
-    They must have the same number of elements, matching the number of arrow
-    locations. *U* and *V* may be masked. Only locations unmasked in
-    *U*, *V*, and *C* will be drawn.
+    *U* and *V* must have the same number of elements, matching the number of
+    arrow locations in  *X*, *Y*. *U* and *V* may be masked. Locations masked
+    in any of *U*, *V*, and *C* will not be drawn.
 
 C : 1D or 2D array-like, optional
     Numeric data that defines the arrow colors by colormapping via *norm* and
@@ -88,38 +83,20 @@ C : 1D or 2D array-like, optional
     use *color* instead.  The size of *C* must match the number of arrow
     locations.
 
-units : {'width', 'height', 'dots', 'inches', 'x', 'y', 'xy'}, default: 'width'
-    The arrow dimensions (except for *length*) are measured in multiples of
-    this unit.
-
-    The following values are supported:
-
-    - 'width', 'height': The width or height of the axis.
-    - 'dots', 'inches': Pixels or inches based on the figure dpi.
-    - 'x', 'y', 'xy': *X*, *Y* or :math:`\\sqrt{X^2 + Y^2}` in data units.
-
-    The arrows scale differently depending on the units.  For
-    'x' or 'y', the arrows get larger as one zooms in; for other
-    units, the arrow size is independent of the zoom state.  For
-    'width or 'height', the arrow size increases with the width and
-    height of the axes, respectively, when the window is resized;
-    for 'dots' or 'inches', resizing does not change the arrows.
-
 angles : {'uv', 'xy'} or array-like, default: 'uv'
     Method for determining the angle of the arrows.
 
-    - 'uv': The arrow axis aspect ratio is 1 so that
-      if *U* == *V* the orientation of the arrow on the plot is 45 degrees
-      counter-clockwise from the horizontal axis (positive to the right).
+    - 'uv': Arrow direction in screen coordinates. Use this if the arrows
+      symbolize a quantity that is not based on *X*, *Y* data coordinates.
 
-      Use this if the arrows symbolize a quantity that is not based on
-      *X*, *Y* data coordinates.
+      If *U* == *V* the orientation of the arrow on the plot is 45 degrees
+      counter-clockwise from the  horizontal axis (positive to the right).
 
-    - 'xy': Arrows point from (x, y) to (x+u, y+v).
-      Use this for plotting a gradient field, for example.
+    - 'xy': Arrow direction in data coordinates, i.e. the arrows point from
+      (x, y) to (x+u, y+v). Use this e.g. for plotting a gradient field.
 
-    - Alternatively, arbitrary angles may be specified explicitly as an array
-      of values in degrees, counter-clockwise from the horizontal axis.
+    - Arbitrary angles may be specified explicitly as an array of values
+      in degrees, counter-clockwise from the horizontal axis.
 
       In this case *U*, *V* is only used to determine the length of the
       arrows.
@@ -127,7 +104,15 @@ angles : {'uv', 'xy'} or array-like, default: 'uv'
     Note: inverting a data axis will correspondingly invert the
     arrows only with ``angles='xy'``.
 
+pivot : {'tail', 'mid', 'middle', 'tip'}, default: 'tail'
+    The part of the arrow that is anchored to the *X*, *Y* grid. The arrow
+    rotates about this point.
+
+    'mid' is a synonym for 'middle'.
+
 scale : float, optional
+    Scales the length of the arrow inversely.
+
     Number of data units per arrow length unit, e.g., m/s per plot width; a
     smaller scale parameter makes the arrow longer. Default is *None*.
 
@@ -149,19 +134,42 @@ scale_units : {'width', 'height', 'dots', 'inches', 'x', 'y', 'xy'}, optional
     the same units as x and y, use
     ``angles='xy', scale_units='xy', scale=1``.
 
+units : {'width', 'height', 'dots', 'inches', 'x', 'y', 'xy'}, default: 'width'
+    Affects the arrow size (except for the length). In particular, the shaft
+    *width* is measured in multiples of this unit.
+
+    Supported values are:
+
+    - 'width', 'height': The width or height of the Axes.
+    - 'dots', 'inches': Pixels or inches based on the figure dpi.
+    - 'x', 'y', 'xy': *X*, *Y* or :math:`\\sqrt{X^2 + Y^2}` in data units.
+
+    The following table summarizes how these values affect the visible arrow
+    size under zooming and figure size changes:
+
+    =================  =================   ==================
+    units              zoom                figure size change
+    =================  =================   ==================
+    'x', 'y', 'xy'     arrow size scales   —
+    'width', 'height'  —                   arrow size scales
+    'dots', 'inches'   —                   —
+    =================  =================   ==================
+
 width : float, optional
-    Shaft width in arrow units; default depends on choice of units,
-    above, and number of vectors; a typical starting value is about
-    0.005 times the width of the plot.
+    Shaft width in arrow units. All head parameters are relative to *width*.
+
+    The default depends on choice of *units* above, and number of vectors;
+    a typical starting value is about 0.005 times the width of the plot.
 
 headwidth : float, default: 3
-    Head width as multiple of shaft width.
+    Head width as multiple of shaft *width*. See the notes below.
 
 headlength : float, default: 5
-    Head length as multiple of shaft width.
+    Head length as multiple of shaft *width*. See the notes below.
 
 headaxislength : float, default: 4.5
-    Head length at shaft intersection.
+    Head length at shaft intersection as multiple of shaft *width*.
+    See the notes below.
 
 minshaft : float, default: 1
     Length below which arrow scales, in units of head length. Do not
@@ -171,12 +179,6 @@ minlength : float, default: 1
     Minimum length as a multiple of shaft width; if an arrow length
     is less than this, plot a dot (hexagon) of this diameter instead.
 
-pivot : {'tail', 'mid', 'middle', 'tip'}, default: 'tail'
-    The part of the arrow that is anchored to the *X*, *Y* grid. The arrow
-    rotates about this point.
-
-    'mid' is a synonym for 'middle'.
-
 color : color or color sequence, optional
     Explicit color(s) for the arrows. If *C* has been set, *color* has no
     effect.
@@ -200,9 +202,34 @@ Returns
 See Also
 --------
 .Axes.quiverkey : Add a key to a quiver plot.
-""" % docstring.interpd.params
 
-docstring.interpd.update(quiver_doc=_quiver_doc)
+Notes
+-----
+
+**Arrow shape**
+
+The arrow is drawn as a polygon using the nodes as shown below. The values
+*headwidth*, *headlength*, and *headaxislength* are in units of *width*.
+
+.. image:: /_static/quiver_sizes.svg
+   :width: 500px
+
+The defaults give a slightly swept-back arrow. Here are some guidelines how to
+get other head shapes:
+
+- To make the head a triangle, make *headaxislength* the same as *headlength*.
+- To make the arrow more pointed, reduce *headwidth* or increase *headlength*
+  and *headaxislength*.
+- To make the head smaller relative to the shaft, scale down all the head
+  parameters proportionally.
+- To remove the head completely, set all *head* parameters to 0.
+- To get a diamond-shaped head, make *headaxislength* larger than *headlength*.
+- Warning: For *headaxislength* < (*headlength* / *headwidth*), the "headaxis"
+  nodes (i.e. the ones connecting the head with the shaft) will protrude out
+  of the head in forward direction so that the arrow head looks broken.
+""" % _docstring.interpd.params
+
+_docstring.interpd.update(quiver_doc=_quiver_doc)
 
 
 class QuiverKey(martist.Artist):
@@ -213,8 +240,7 @@ class QuiverKey(martist.Artist):
 
     def __init__(self, Q, X, Y, U, label,
                  *, angle=0, coordinates='axes', color=None, labelsep=0.1,
-                 labelpos='N', labelcolor=None, fontproperties=None,
-                 **kw):
+                 labelpos='N', labelcolor=None, fontproperties=None, **kwargs):
         """
         Add a key to a quiver plot.
 
@@ -227,7 +253,7 @@ class QuiverKey(martist.Artist):
 
         Parameters
         ----------
-        Q : `matplotlib.quiver.Quiver`
+        Q : `~matplotlib.quiver.Quiver`
             A `.Quiver` object as returned by a call to `~.Axes.quiver()`.
         X, Y : float
             The location of the key.
@@ -276,15 +302,12 @@ class QuiverKey(martist.Artist):
         self.labelpos = labelpos
         self.labelcolor = labelcolor
         self.fontproperties = fontproperties or dict()
-        self.kw = kw
-        _fp = self.fontproperties
-        # boxprops = dict(facecolor='red')
+        self.kw = kwargs
         self.text = mtext.Text(
-            text=label,  # bbox=boxprops,
+            text=label,
             horizontalalignment=self.halign[self.labelpos],
             verticalalignment=self.valign[self.labelpos],
-            fontproperties=font_manager.FontProperties._from_any(_fp))
-
+            fontproperties=self.fontproperties)
         if self.labelcolor is not None:
             self.text.set_color(self.labelcolor)
         self._dpi_at_last_init = None
@@ -308,42 +331,33 @@ class QuiverKey(martist.Artist):
                          else 'uv')
                 self.verts = self.Q._make_verts(
                     np.array([u]), np.array([v]), angle)
-            kw = self.Q.polykw
-            kw.update(self.kw)
+            kwargs = self.Q.polykw
+            kwargs.update(self.kw)
             self.vector = mcollections.PolyCollection(
-                                        self.verts,
-                                        offsets=[(self.X, self.Y)],
-                                        transOffset=self.get_transform(),
-                                        **kw)
+                self.verts,
+                offsets=[(self.X, self.Y)],
+                offset_transform=self.get_transform(),
+                **kwargs)
             if self.color is not None:
                 self.vector.set_color(self.color)
             self.vector.set_transform(self.Q.get_transform())
             self.vector.set_figure(self.get_figure())
             self._dpi_at_last_init = self.Q.axes.figure.dpi
 
-    def _text_x(self, x):
-        if self.labelpos == 'E':
-            return x + self.labelsep
-        elif self.labelpos == 'W':
-            return x - self.labelsep
-        else:
-            return x
-
-    def _text_y(self, y):
-        if self.labelpos == 'N':
-            return y + self.labelsep
-        elif self.labelpos == 'S':
-            return y - self.labelsep
-        else:
-            return y
+    def _text_shift(self):
+        return {
+            "N": (0, +self.labelsep),
+            "S": (0, -self.labelsep),
+            "E": (+self.labelsep, 0),
+            "W": (-self.labelsep, 0),
+        }[self.labelpos]
 
     @martist.allow_rasterization
     def draw(self, renderer):
         self._init()
         self.vector.draw(renderer)
-        x, y = self.get_transform().transform((self.X, self.Y))
-        self.text.set_x(self._text_x(x))
-        self.text.set_y(self._text_y(y))
+        pos = self.get_transform().transform((self.X, self.Y))
+        self.text.set_position(pos + self._text_shift())
         self.text.draw(renderer)
         self.stale = False
 
@@ -392,20 +406,19 @@ def _parse_args(*args, caller_name='function'):
     """
     X = Y = C = None
 
-    len_args = len(args)
-    if len_args == 2:
+    nargs = len(args)
+    if nargs == 2:
         # The use of atleast_1d allows for handling scalar arguments while also
         # keeping masked arrays
         U, V = np.atleast_1d(*args)
-    elif len_args == 3:
+    elif nargs == 3:
         U, V, C = np.atleast_1d(*args)
-    elif len_args == 4:
+    elif nargs == 4:
         X, Y, U, V = np.atleast_1d(*args)
-    elif len_args == 5:
+    elif nargs == 5:
         X, Y, U, V, C = np.atleast_1d(*args)
     else:
-        raise TypeError(f'{caller_name} takes 2-5 positional arguments but '
-                        f'{len_args} were given')
+        raise _api.nargs_error(caller_name, takes="from 2 to 5", given=nargs)
 
     nr, nc = (1, U.shape[0]) if U.ndim == 1 else U.shape
 
@@ -450,11 +463,11 @@ class Quiver(mcollections.PolyCollection):
 
     _PIVOT_VALS = ('tail', 'middle', 'tip')
 
-    @docstring.Substitution(_quiver_doc)
+    @_docstring.Substitution(_quiver_doc)
     def __init__(self, ax, *args,
                  scale=None, headwidth=3, headlength=5, headaxislength=4.5,
                  minshaft=1, minlength=1, units='width', scale_units=None,
-                 angles='uv', width=None, color='k', pivot='tail', **kw):
+                 angles='uv', width=None, color='k', pivot='tail', **kwargs):
         """
         The constructor takes one required argument, an Axes
         instance, followed by the args and kwargs described
@@ -462,7 +475,7 @@ class Quiver(mcollections.PolyCollection):
         %s
         """
         self._axes = ax  # The attr actually set by the Artist.axes property.
-        X, Y, U, V, C = _parse_args(*args, caller_name='quiver()')
+        X, Y, U, V, C = _parse_args(*args, caller_name='quiver')
         self.X = X
         self.Y = Y
         self.XY = np.column_stack((X, Y))
@@ -483,12 +496,12 @@ class Quiver(mcollections.PolyCollection):
         self.pivot = pivot.lower()
         _api.check_in_list(self._PIVOT_VALS, pivot=self.pivot)
 
-        self.transform = kw.pop('transform', ax.transData)
-        kw.setdefault('facecolors', color)
-        kw.setdefault('linewidths', (0,))
-        super().__init__([], offsets=self.XY, transOffset=self.transform,
-                         closed=False, **kw)
-        self.polykw = kw
+        self.transform = kwargs.pop('transform', ax.transData)
+        kwargs.setdefault('facecolors', color)
+        kwargs.setdefault('linewidths', (0,))
+        super().__init__([], offsets=self.XY, offset_transform=self.transform,
+                         closed=False, **kwargs)
+        self.polykw = kwargs
         self.set_UVC(U, V, C)
         self._dpi_at_last_init = None
 
@@ -515,8 +528,8 @@ class Quiver(mcollections.PolyCollection):
 
     def get_datalim(self, transData):
         trans = self.get_transform()
-        transOffset = self.get_offset_transform()
-        full_transform = (trans - transData) + (transOffset - transData)
+        offset_trf = self.get_offset_transform()
+        full_transform = (trans - transData) + (offset_trf - transData)
         XY = full_transform.transform(self.XY)
         bbox = transforms.Bbox.null()
         bbox.update_from_data_xy(XY, ignore=True)
@@ -558,36 +571,18 @@ class Quiver(mcollections.PolyCollection):
         self.stale = True
 
     def _dots_per_unit(self, units):
-        """
-        Return a scale factor for converting from units to pixels
-        """
-        if units in ('x', 'y', 'xy'):
-            if units == 'x':
-                dx0 = self.axes.viewLim.width
-                dx1 = self.axes.bbox.width
-            elif units == 'y':
-                dx0 = self.axes.viewLim.height
-                dx1 = self.axes.bbox.height
-            else:  # 'xy' is assumed
-                dxx0 = self.axes.viewLim.width
-                dxx1 = self.axes.bbox.width
-                dyy0 = self.axes.viewLim.height
-                dyy1 = self.axes.bbox.height
-                dx1 = np.hypot(dxx1, dyy1)
-                dx0 = np.hypot(dxx0, dyy0)
-            dx = dx1 / dx0
-        else:
-            if units == 'width':
-                dx = self.axes.bbox.width
-            elif units == 'height':
-                dx = self.axes.bbox.height
-            elif units == 'dots':
-                dx = 1.0
-            elif units == 'inches':
-                dx = self.axes.figure.dpi
-            else:
-                raise ValueError('unrecognized units')
-        return dx
+        """Return a scale factor for converting from units to pixels."""
+        bb = self.axes.bbox
+        vl = self.axes.viewLim
+        return _api.check_getitem({
+            'x': bb.width / vl.width,
+            'y': bb.height / vl.height,
+            'xy': np.hypot(*bb.size) / np.hypot(*vl.size),
+            'width': bb.width,
+            'height': bb.height,
+            'dots': 1.,
+            'inches': self.axes.figure.dpi,
+        }, units=units)
 
     def _set_transform(self):
         """
@@ -727,7 +722,7 @@ class Quiver(mcollections.PolyCollection):
         # Mask handling is deferred to the caller, _make_verts.
         return X, Y
 
-    quiver_doc = _quiver_doc
+    quiver_doc = _api.deprecated("3.7")(property(lambda self: _quiver_doc))
 
 
 _barbs_doc = r"""
@@ -735,7 +730,7 @@ Plot a 2D field of barbs.
 
 Call signature::
 
-  barbs([X, Y], U, V, [C], **kw)
+  barbs([X, Y], U, V, [C], **kwargs)
 
 Where *X*, *Y* define the barb locations, *U*, *V* define the barb
 directions, and *C* optionally sets the color.
@@ -864,9 +859,9 @@ data : indexable object, optional
     arguments:
 
     %(PolyCollection:kwdoc)s
-""" % docstring.interpd.params
+""" % _docstring.interpd.params
 
-docstring.interpd.update(barbs_doc=_barbs_doc)
+_docstring.interpd.update(barbs_doc=_barbs_doc)
 
 
 class Barbs(mcollections.PolyCollection):
@@ -883,14 +878,16 @@ class Barbs(mcollections.PolyCollection):
     From there :meth:`_make_barbs` is used to find the vertices of the
     polygon to represent the barb based on this information.
     """
+
     # This may be an abuse of polygons here to render what is essentially maybe
     # 1 triangle and a series of lines.  It works fine as far as I can tell
     # however.
-    @docstring.interpd
+
+    @_docstring.interpd
     def __init__(self, ax, *args,
                  pivot='tip', length=7, barbcolor=None, flagcolor=None,
                  sizes=None, fill_empty=False, barb_increments=None,
-                 rounding=True, flip_barb=False, **kw):
+                 rounding=True, flip_barb=False, **kwargs):
         """
         The constructor takes one required argument, an Axes
         instance, followed by the args and kwargs described
@@ -902,11 +899,9 @@ class Barbs(mcollections.PolyCollection):
         self.barb_increments = barb_increments or dict()
         self.rounding = rounding
         self.flip = np.atleast_1d(flip_barb)
-        transform = kw.pop('transform', ax.transData)
+        transform = kwargs.pop('transform', ax.transData)
         self._pivot = pivot
         self._length = length
-        barbcolor = barbcolor
-        flagcolor = flagcolor
 
         # Flagcolor and barbcolor provide convenience parameters for
         # setting the facecolor and edgecolor, respectively, of the barb
@@ -914,68 +909,68 @@ class Barbs(mcollections.PolyCollection):
         # rest of the barb by default
 
         if None in (barbcolor, flagcolor):
-            kw['edgecolors'] = 'face'
+            kwargs['edgecolors'] = 'face'
             if flagcolor:
-                kw['facecolors'] = flagcolor
+                kwargs['facecolors'] = flagcolor
             elif barbcolor:
-                kw['facecolors'] = barbcolor
+                kwargs['facecolors'] = barbcolor
             else:
                 # Set to facecolor passed in or default to black
-                kw.setdefault('facecolors', 'k')
+                kwargs.setdefault('facecolors', 'k')
         else:
-            kw['edgecolors'] = barbcolor
-            kw['facecolors'] = flagcolor
+            kwargs['edgecolors'] = barbcolor
+            kwargs['facecolors'] = flagcolor
 
         # Explicitly set a line width if we're not given one, otherwise
         # polygons are not outlined and we get no barbs
-        if 'linewidth' not in kw and 'lw' not in kw:
-            kw['linewidth'] = 1
+        if 'linewidth' not in kwargs and 'lw' not in kwargs:
+            kwargs['linewidth'] = 1
 
         # Parse out the data arrays from the various configurations supported
-        x, y, u, v, c = _parse_args(*args, caller_name='barbs()')
+        x, y, u, v, c = _parse_args(*args, caller_name='barbs')
         self.x = x
         self.y = y
         xy = np.column_stack((x, y))
 
         # Make a collection
         barb_size = self._length ** 2 / 4  # Empirically determined
-        super().__init__([], (barb_size,), offsets=xy, transOffset=transform,
-                         **kw)
+        super().__init__(
+            [], (barb_size,), offsets=xy, offset_transform=transform, **kwargs)
         self.set_transform(transforms.IdentityTransform())
 
         self.set_UVC(u, v, c)
 
     def _find_tails(self, mag, rounding=True, half=5, full=10, flag=50):
         """
-        Find how many of each of the tail pieces is necessary.  Flag
-        specifies the increment for a flag, barb for a full barb, and half for
-        half a barb. Mag should be the magnitude of a vector (i.e., >= 0).
+        Find how many of each of the tail pieces is necessary.
 
-        This returns a tuple of:
+        Parameters
+        ----------
+        mag : `~numpy.ndarray`
+            Vector magnitudes; must be non-negative (and an actual ndarray).
+        rounding : bool, default: True
+            Whether to round or to truncate to the nearest half-barb.
+        half, full, flag : float, defaults: 5, 10, 50
+            Increments for a half-barb, a barb, and a flag.
 
-            (*number of flags*, *number of barbs*, *half_flag*, *empty_flag*)
-
-        The bool *half_flag* indicates whether half of a barb is needed,
-        since there should only ever be one half on a given
-        barb. *empty_flag* flag is an array of flags to easily tell if
-        a barb is empty (too low to plot any barbs/flags.
+        Returns
+        -------
+        n_flags, n_barbs : int array
+            For each entry in *mag*, the number of flags and barbs.
+        half_flag : bool array
+            For each entry in *mag*, whether a half-barb is needed.
+        empty_flag : bool array
+            For each entry in *mag*, whether nothing is drawn.
         """
-
         # If rounding, round to the nearest multiple of half, the smallest
         # increment
         if rounding:
-            mag = half * (mag / half + 0.5).astype(int)
-
-        num_flags = np.floor(mag / flag).astype(int)
-        mag = mag % flag
-
-        num_barb = np.floor(mag / full).astype(int)
-        mag = mag % full
-
+            mag = half * np.around(mag / half)
+        n_flags, mag = divmod(mag, flag)
+        n_barb, mag = divmod(mag, full)
         half_flag = mag >= half
-        empty_flag = ~(half_flag | (num_flags > 0) | (num_barb > 0))
-
-        return num_flags, num_barb, half_flag, empty_flag
+        empty_flag = ~(half_flag | (n_flags > 0) | (n_barb > 0))
+        return n_flags.astype(int), n_barb.astype(int), half_flag, empty_flag
 
     def _make_barbs(self, u, v, nflags, nbarbs, half_barb, empty_flag, length,
                     pivot, sizes, fill_empty, flip):
@@ -1147,9 +1142,8 @@ class Barbs(mcollections.PolyCollection):
             _check_consistent_shapes(x, y, u, v, flip)
 
         magnitude = np.hypot(u, v)
-        flags, barbs, halves, empty = self._find_tails(magnitude,
-                                                       self.rounding,
-                                                       **self.barb_increments)
+        flags, barbs, halves, empty = self._find_tails(
+            magnitude, self.rounding, **self.barb_increments)
 
         # Get the vertices for each of the barbs
 
@@ -1185,4 +1179,4 @@ class Barbs(mcollections.PolyCollection):
         super().set_offsets(xy)
         self.stale = True
 
-    barbs_doc = _barbs_doc
+    barbs_doc = _api.deprecated("3.7")(property(lambda self: _barbs_doc))
